@@ -97,6 +97,8 @@ MOVETEXT_REGEX = re.compile(r"""
         |[PNBRQK]?@[a-h][1-8]
         |--
         |Z0
+        |0000
+        |@@@@
         |O-O(?:-O)?
         |0-0(?:-0)?
     )
@@ -441,21 +443,7 @@ class GameNode:
         arrows = []
         for match in ARROWS_REGEX.finditer(self.comment):
             for group in match.group(1).split(","):
-                color = "green"
-                if group[0] == "R":
-                    color = "red"
-                elif group[0] == "Y":
-                    color = "yellow"
-                elif group[0] == "B":
-                    color = "blue"
-
-                tail = chess.SQUARE_NAMES.index(group[1:3])
-                if len(group) == 5:
-                    head = chess.SQUARE_NAMES.index(group[3:5])
-                else:
-                    head = tail
-
-                arrows.append(chess.svg.Arrow(tail, head, color=color))
+                arrows.append(chess.svg.Arrow.from_pgn(group))
 
         return arrows
 
@@ -464,27 +452,16 @@ class GameNode:
         Replaces all valid ``[%csl ...]`` and ``[%cal ...]`` annotations in
         the comment of this node or adds new ones.
         """
-        csl = []
-        cal = []
+        csl: List[str] = []
+        cal: List[str] = []
 
         for arrow in arrows:
             try:
-                tail, head, color = arrow.tail, arrow.head, arrow.color  # type: ignore
-                if color == "red":
-                    color = "R"
-                elif color == "yellow":
-                    color = "Y"
-                elif color == "blue":
-                    color = "B"
-                else:
-                    color = "G"
-            except AttributeError:
                 tail, head = arrow  # type: ignore
-                color = "G"
-            if tail == head:
-                csl.append(f"{color}{chess.SQUARE_NAMES[tail]}")
-            else:
-                cal.append(f"{color}{chess.SQUARE_NAMES[tail]}{chess.SQUARE_NAMES[head]}")
+                arrow = chess.svg.Arrow(tail, head)
+            except TypeError:
+                pass
+            (csl if arrow.tail == arrow.head else cal).append(arrow.pgn())  # type: ignore
 
         self.comment = ARROWS_REGEX.sub("", self.comment).strip()
 
@@ -939,13 +916,13 @@ class BaseVisitor(abc.ABC, Generic[ResultT]):
 
         You can override the default implementation to work around specific
         quirks of your input format.
-        """
-        # Replace zeros with correct castling notation.
-        if san == "0-0":
-            san = "O-O"
-        elif san == "0-0-0":
-            san = "O-O-O"
 
+        .. deprecated:: 1.1
+            This method is very limited, because it is only called on moves
+            that the parser recognizes in the first place. Instead of adding
+            workarounds here, please report common quirks so that
+            they can be handled for everyone.
+        """
         return board.parse_san(san)
 
     def visit_move(self, board: chess.Board, move: chess.Move) -> None:
